# Expected Parrot Domain-Specific Language 
<p align="center">
  <img src="https://github.com/expectedparrot/edsl/blob/main/static/logo.png?raw=true" alt="edsl.png" width="100"/>
</p>

The Expected Parrot Domain-Specific Language (EDSL) package lets you conduct computational social science and market research with AI. Use it to design surveys and experiments, simulate responses with large language models, and perform data labeling and other research tasks. EDSL comes with built-in methods for analyzing, visualizing and sharing your results. 

## 🔗 Links
- PyPI: https://pypi.org/project/edsl/
- Documentation: https://docs.expectedparrot.com
- Getting started: https://docs.expectedparrot.com/en/latest/starter_tutorial.html
- Discord: https://discord.com/invite/mxAYkjfy9m


## 💡 Contributions, Feature Requests & Bugs
Interested in contributing? Want us to add a new feature? Found a nasty bug that you would like us to squash? Please send us an email at info@expectedparrot.com or message us at our Discord server.


## 💻 Getting started
EDSL is compatible with Python 3.9 - 3.12.
```
pip install edsl
```

- Read the docs at http://docs.expectedparrot.com.
- See https://docs.expectedparrot.com/en/latest/starter_tutorial.html for examples and tutorials.

## 🔧 Dependencies
API keys for LLMs that you want to use, stored in a `.env` file
